@@ -1,5 +1,5 @@
 package DBIx::Lite;
-$DBIx::Lite::VERSION = '0.28';
+$DBIx::Lite::VERSION = '0.29';
 # ABSTRACT: Chained and minimal ORM
 use strict;
 use warnings;
@@ -130,6 +130,12 @@ sub _autopk {
     }
 }
 
+sub _quote {
+    my $self = shift;
+    
+    return $self->{abstract}->_quote(@_);
+}
+
 1;
 
 __END__
@@ -144,7 +150,7 @@ DBIx::Lite - Chained and minimal ORM
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
