@@ -1,5 +1,5 @@
 package DBIx::Lite::ResultSet;
-$DBIx::Lite::ResultSet::VERSION = '0.28';
+$DBIx::Lite::ResultSet::VERSION = '0.29';
 use strict;
 use warnings;
 
@@ -144,9 +144,6 @@ sub where_sql {
 sub select_sql {
     my $self = shift;
     
-    # import the quoting subroutine from SQL::Abstract
-    my $quote = sub { $self->{dbix_lite}->{abstract}->_quote(@_) };
-    
     # prepare names of columns to be selected
     my @cols = ();
     my $cur_table_prefix = $self->_table_alias($self->{cur_table}{name}, 'select');
@@ -188,7 +185,7 @@ sub select_sql {
             $col1 =~ s/^$join->{cur_table}{name}\./$left_table_prefix./;
             
             # prepend table alias to the column of the second table
-            $col2 = ($table_alias || $quote->($table_name)) . ".$col2"
+            $col2 = ($table_alias || $self->{dbix_lite}->_quote($table_name)) . ".$col2"
                 unless ref $col2 || $col2 =~ /\./;
             
             # in case the second item is a scalar reference (literal SQL)
@@ -280,6 +277,12 @@ sub insert_sql {
         warn "Attempt to call ->insert() after joining other tables\n";
     }
     
+    if (!%$insert_cols && $self->{dbix_lite}->driver_name eq 'Pg') {
+        # Postgres doesn't support the VALUES () syntax
+        return sprintf "INSERT INTO %s DEFAULT VALUES",
+            $self->{dbix_lite}->_quote($self->{table}{name});
+    }
+    
     return $self->{dbix_lite}->{abstract}->insert(
         $self->{table}{name}, $insert_cols,
     );
@@ -669,7 +672,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 OVERVIEW
 
